"""
┏┓┓ ┏┓┏┓┏┓┳┓┳┓┏┓┳┓ 
┣┫┃ ┣┫┃ ┃┃┣┫┃┃┣ ┣┫ 
┛┗┗┛┛┗┗┛┗┛┛┗┻┛┗┛┛┗ 
(c) 2023 Sam Robson

Alacorder collects case detail PDFs from Alacourt.com and 
processes them into data tables suitable for research purposes.

Dependencies:   python: 3.10+
                brotli: 1.1.0+
                bs4: 0.0.1+
                docxtpl: 0.16.7+
                polars: 0.19.3+
                pymupdf: 1.22.5+
                rich: 13.5.2+
                selenium: 4.10.0+
                typer: 0.9.0+
                xlsxwriter: 3.1.2+
                xlsx2csv: 0.8.1+
                Google Chrome: v75+
"""

from .alac import app

if __name__ == "__main__":
    app()



"""
┏┓┓ ┏┓┏┓┏┓┳┓┳┓┏┓┳┓ 
┣┫┃ ┣┫┃ ┃┃┣┫┃┃┣ ┣┫ 
┛┗┗┛┛┗┗┛┗┛┛┗┻┛┗┛┛┗ 
(c) 2023 Sam Robson

Alacorder collects case detail PDFs from Alacourt.com and 
processes them into data tables suitable for research purposes.

Dependencies:   python: 3.10+
                brotli: 1.1.0+
                bs4: 0.0.1+
                docxtpl: 0.16.7+
                polars: 0.19.3+
                pymupdf: 1.22.5+
                rich: 13.5.2+
                selenium: 4.10.0+
                typer: 0.9.0+
                xlsxwriter: 3.1.2+
                xlsx2csv: 0.8.1+
                Google Chrome: v75+
"""

from .alac import (
    ADOCDriver,
    AlacourtDriver,
    Cases,
    autofilter,
    crawl_adoc,
    fetch_cases,
    get_adc,
    get_address,
    get_address_1,
    get_address_2,
    get_admin_last_update,
    get_admin_updated_by,
    get_agency_ori,
    get_al_institutional_service_num,
    get_alias,
    get_alias2,
    get_amount_due_by_fee_code,
    get_amount_hold_by_fee_code,
    get_amount_paid_by_fee_code,
    get_annulment,
    get_appeal_case_number,
    get_appeal_court,
    get_appeal_date,
    get_appeal_status,
    get_appeal_to,
    get_appeal_to_desc,
    get_appellate_case,
    get_arrearage,
    get_arrest_date,
    get_arresting_agency_type,
    get_arresting_officer,
    get_attorneys,
    get_balance_by_fee_code,
    get_blood_alcohol_content,
    get_bond_amount,
    get_bond_release_date,
    get_bond_type,
    get_bond_type_desc,
    get_bondsman_process_issuance,
    get_bondsman_process_return,
    get_case_action_summary,
    get_case_initiation_date,
    get_case_initiation_type,
    get_case_number,
    get_case_status,
    get_case_type,
    get_case_year,
    get_central_disbursement_division,
    get_city,
    get_clear_date,
    get_collection_status,
    get_comment_1,
    get_comment_2,
    get_commercial_driver_license_required,
    get_commercial_vehicle,
    get_compensatory_damages,
    get_completion_date,
    get_contempt,
    get_continuance_date,
    get_continuance_description,
    get_continuance_reason,
    get_continuances,
    get_cost_paid_by,
    get_country,
    get_county,
    get_court_action,
    get_court_action_code,
    get_court_action_date,
    get_court_action_desc,
    get_custody,
    get_da_mailer,
    get_da_mailer_date,
    get_damage_amt,
    get_defendant_status,
    get_delinquent,
    get_delinquent_date,
    get_description,
    get_disposition_charges,
    get_disposition_date_of_appeal,
    get_disposition_judge,
    get_disposition_type_of_appeal,
    get_dna_test,
    get_dob,
    get_domestic_violence,
    get_driver_license_class,
    get_driver_license_no,
    get_due_date,
    get_enforcement_status,
    get_eyes,
    get_failed_to_appear_date,
    get_filed_date,
    get_filing_charges,
    get_filing_date,
    get_financial_history,
    get_first_date,
    get_first_name,
    get_frequency,
    get_frequency_amt,
    get_general_damages,
    get_hair,
    get_hazardous_materials,
    get_height,
    get_images,
    get_income_withholding_order,
    get_indictment_date,
    get_inpatient_treatment_ordered,
    get_jail_credit_period,
    get_judge,
    get_judgment_for,
    get_jury_demand,
    get_last_name,
    get_last_paid_date,
    get_last_update,
    get_legal_separation,
    get_license_susp_period,
    get_linked_cases,
    get_lower_court_appeal_date,
    get_middle_name,
    get_minstral,
    get_name,
    get_no_damages,
    get_no_of_children,
    get_no_of_defendants,
    get_no_of_plaintiffs,
    get_num_of_trial_days,
    get_number_of_previous_continuances,
    get_number_of_subpoenas,
    get_number_of_warrants,
    get_offense_date,
    get_origin_of_appeal,
    get_origin_of_case,
    get_over_under_paid,
    get_parties,
    get_passengers_present,
    get_paternity,
    get_payment_frequency,
    get_payor,
    get_phone,
    get_placement_status,
    get_pre_terms_date,
    get_pretrial,
    get_pretrial_date,
    get_pretrial_terms,
    get_previous_dui_convictions,
    get_probation_begin_date,
    get_probation_office_name,
    get_probation_office_number,
    get_probation_period,
    get_probation_revoke,
    get_punitive_damages,
    get_race,
    get_related_cases,
    get_restitution,
    get_retrieved,
    get_rule_20,
    get_sentence_date,
    get_sentence_end_date,
    get_sentence_provisions,
    get_sentence_requirements_completed,
    get_sentence_start_date,
    get_settings,
    get_sex,
    get_short_case_number,
    get_speed,
    get_speed_limit,
    get_ssn,
    get_state,
    get_state_id,
    get_style,
    get_support,
    get_surety_code,
    get_suspension_date,
    get_tag_number,
    get_tbnv1,
    get_tbnv2,
    get_ticket_number,
    get_total_amount_due,
    get_total_amount_hold,
    get_total_amount_paid,
    get_total_balance,
    get_track,
    get_traffic_citation_number,
    get_transfer_desc,
    get_transfer_reason,
    get_transfer_to_admin_doc_date,
    get_trial_type,
    get_turnover_amt,
    get_turnover_date,
    get_uifsa,
    get_updated_by,
    get_vehicle_desc,
    get_vehicle_state,
    get_vehicle_year,
    get_warrant_action_date,
    get_warrant_action_description,
    get_warrant_action_status,
    get_warrant_issuance_date,
    get_warrant_issuance_description,
    get_warrant_issuance_status,
    get_warrant_location_description,
    get_warrant_location_status,
    get_warrant_mailer,
    get_warrant_mailer_date,
    get_weight,
    get_witnesses,
    get_youthful_date,
    get_zip_code,
    make_archive,
    make_summary,
    make_table,
    party_search,
    read,
    rename_cases,
    search_adoc,
    write,
)
